@@ -1,7 +1,7 @@
 #!/usr/bin/perl
-# DocumentId:	$Id: debarchiver.pl 2210 2006-07-05 21:52:53Z ola $
+# DocumentId:	$Id: debarchiver.pl 2372 2006-12-08 21:04:56Z ola $
 # Author:	$Author: ola $
-# Date:		$Date: 2006-07-05 23:52:53 +0200 (ons, 05 jul 2006) $
+# Date:		$Date: 2006-12-08 22:04:56 +0100 (fre, 08 dec 2006) $
 # Version:	$Revision: 1.49 $
 # Summary:
 #	This program reads a config file, traverse through all .changes files
@@ -12,8 +12,12 @@
 #    Copyright (C) 2005      Joel Baker <lucifer@lightbearer.com>
 #    Copyright (C) 2005      Daniel Leidert <daniel.leidert@wgdd.de>
 #    Copyright (C) 2005      Bob Proulx <bob@proulx.com>
+#    Copyright (C) 2005-2006 Valry Perrin <valery.perrin@free.fr>
 #    Copyright (C) 2006      Yaroslav Halchenko <debian@onerussian.com>
 #    Copyright (C) 2006      Jrmy Bobbio <jeremy.bobbio@etu.upmc.fr>
+#    Copyright (C) 2006      Michael Hanke <michael.hanke@gmail.com>
+#    Copyright (C) 2006      Martin F Krafft <madduck@debian.org>
+#    Copyright (C) 2006      Hkon Stordahl <haastord@online.no>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -106,7 +110,7 @@ $CChanges = "";
 %release = ();
 # The criteria to use for which binary packages that does not need a .changes
 # file.
-$distinputcriteria = "^kernel.*\\.deb\$";
+$distinputcriteria = "^linux.*\\.deb\$";
 # Extra directories with specified destination. Where to find for distinput
 # files.
 %distinputdirs = (
@@ -118,8 +122,8 @@ $distinputcriteria = "^kernel.*\\.deb\$";
 @distributions = ('stable', 'testing', 'unstable');
 
 %distmapping = (
-		stable => 'sarge',
-		testing => 'etch',
+		stable => 'etch',
+		testing => 'lenny',
 		unstable => 'sid'
 		);
 
@@ -266,103 +270,106 @@ else {
 #  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
 #             Ola Lundqvist <opal@debian.org>
 #       Default major section function.
+#  2006-11-28 Ola Lundqvist <opal@debian.org>
+#       Sorted options in alphabetical order.
 
-$version = "0.6.2";
+$version = "0.7.0";
 $versionstring = "Debian package archiver, version $version";
 
 $help =
     "Usage: debarchiver [option(s)]
 
 options:
- --debug-level level	What information that should be printed.
-  --dl level		 1 = critical, 2 = error, 3 = normal,
-			 4 = message, 5 = debug, 6 = verbose debug (modules).
- --quit-level level	On what level to quit the application, see debug level.
- -v | --version		Prints the version string.
- --help			Prints this information.
- --copycmd		The install command to use, default $copycmd.
-			 Both packages and .changes files are installed using
-			 this command.
- --configfile file      Specify an extra configuration file to read. Will be read
-                         after etc config and user config file.
- --movecmd		Command to move files (currently not used at all).
- --mailcmd		The mail command to use, default $mail.
- --rmcmd		The remove command to use, default $rmcmd.
-			 This can be used to move away the old packages to
-			 some other place.
- --instcmd		DEPRICATED!
- --majordefault section Default major section to use if undefined
-                        (default: main)
- -d | --dest dir       	Destination directory. The base directory where all
-  --destdir dir		 the distribution packages reside. Here the
-			 \$distrib/\$major/\$arch/\$section directory structure
-			 will be created. Default $destdir, relative to the
-			 input directory.
- --scandetect | -s      Scan using apt-ftparchive or dpkg-scan* depending on
-                         what is installed on the system. This is the
-                         recommended way. Only use --index or --autoscan if
-                         you know what you are doing.
- --index | -x           Automatically run apt-ftparchive after all new packages
-                         are installed.  Use this *or* --autoscan, not both.
- -i | --input dir      	This is the directory where debarchiver is looking for
-  --indir dir		 new packages corresponding *.changes files that
-  --inputdir dir	 should be installed to the --dest directory.
-			 The default directory is
-			 /var/lib/debarchiver/incoming.
- --cachedir dir         The apt-ftparchive package cache directory, if --index
-                         is used.  Default $cachedir.
- --lockfile file	The lockfile to use, default $lockfile.
- --cinstall dir		Where the .changes file will be installed to,
-			 empty string to remove it instead, default $cinstall.
- --distinputcriteria     The criteria for which binary packages that should be
-			 installed even if it does not have a .changes file,
-			 default $distinputcriteria.
- -o | --addoverride    	Automaticly add new packages to the override file.
+ -a | --autoscan       	Does both --autoscanpackages and --autoscansources.
+                         Use this *or* --index, not both.
+ --autoscanall		Same as --scanall --autoscan.
  --autoscanpackages	Automaticly run dpkg-scanpackages after all new
 			 packages are installed.
  --autoscansources	Automaticly run dpkg-scansources after all new
 			 packages are installed.
  -b | --bzip            Create bzip2 compressed Packages.bz2 and Sources.bz2
 			 files. 
- -a | --autoscan       	Does both --autoscanpackages and --autoscansources.
-                         Use this *or* --index, not both.
- --scanall		Scan all distributions, sections, etc.
- --autoscanall		Same as --scanall --autoscan.
- --nosort		Do not sort packages.
- --nostructurefix	Do not create directories and touch Package files.
- --scanonly             Same as --nosort --nostructurefix.
+ --cachedir dir         The apt-ftparchive package cache directory, if --index
+                         is used.  Default $cachedir.
+ --cinstall dir		Where the .changes file will be installed to,
+			 empty string to remove it instead, default $cinstall.
+ --configfile file      Specify an extra configuration file to read. Will be read
+                         after etc config and user config file.
+ --copycmd		The install command to use, default $copycmd.
+			 Both packages and .changes files are installed using
+			 this command.
+ -d | --dest dir       	Destination directory. The base directory where all
+  --destdir dir		 the distribution packages reside. Here the
+			 \$distrib/\$major/\$arch/\$section directory structure
+			 will be created.
+                         Default $destdir,
+                         relative to the input directory.
+ --debug-level level	What information that should be printed.
+  --dl level		 1 = critical, 2 = error, 3 = normal,
+			 4 = message, 5 = debug, 6 = verbose debug (modules).
+ --distinputcriteria     The criteria for which binary packages that should be
+			 installed even if it does not have a .changes file,
+			 default $distinputcriteria.
  --gpgkey               GnuPG key to use to sign the archive.
  --gpgpassfile          File to provide password to GnuPG.
+ --help			Prints this information.
+ -i | --input dir      	This is the directory where debarchiver is looking for
+  --indir dir		 new packages corresponding *.changes files that
+  --inputdir dir	 should be installed to the --dest directory.
+			 The default directory is
+			 /var/lib/debarchiver/incoming.
+ --index | -x           Automatically run apt-ftparchive after all new packages
+                         are installed.  Use this *or* --autoscan, not both.
+ --instcmd		DEPRICATED!
+ --lockfile file	The lockfile to use, default $lockfile.
+ --mailcmd		The mail command to use, default $mail.
+ --majordefault section Default major section to use if undefined
+                        (default: main)
+ --movecmd		Command to move files (currently not used at all).
+ --nosort		Do not sort packages.
+ --nostructurefix	Do not create directories and touch Package files.
+ -o | --addoverride    	Automaticly add new packages to the override file.
+ --rmcmd		The remove command to use, default $rmcmd.
+			 This can be used to move away the old packages to
+			 some other place.
+ --quit-level level	On what level to quit the application, see debug level.
+ --scanall		Scan all distributions, sections, etc.
+ --scandetect | -s      Scan using apt-ftparchive or dpkg-scan* depending on
+                         what is installed on the system. This is the
+                         recommended way. Only use --index or --autoscan if
+                         you know what you are doing.
+ --scanonly             Same as --nosort --nostructurefix.
+ -v | --version		Prints the version string.
 
 You can also place config files with the following names (in following order)
-$etcconfigfile, $userconfigfile and $inputconfigfile".
-    "(relative to input dir) that will be read before the arguments to this program
+$etcconfigfile, $userconfigfile and $inputconfigfile
+(relative to input dir), that will be read before the arguments to this program
 will be parsed. Here you can change the following variables
-	\$destdir      	The destination directory (see --destdir above).
-	\$majordefault  Default major section (see --majordefault above).
-	\$inputdir	The input directory (no effect in $inputconfigfile).
         \$cachedir	The cache directory for apt-ftparchive, used if
 			--index is used.
-	\$copycmd	The install command (see --copycmd).
-	\$movecmd	The move command (see --movecmd).
-	\$rmcmd		The remove command (see --rmcmd above).
 	\$cinstall	Where the .changes files are installed
 			 (see --cinstall above).
+	\$copycmd	The install command (see --copycmd).
+	\$destdir      	The destination directory (see --destdir above).
         \$distinputcriteria The criteria for which packages that should be
 			 installed even if it does not have a .changes file,
 			 default $distinputcriteria.
         \%distinputdirs The directories (distribution => dir) that should be
 			 searched for extra binary packages that does not need
 			 a .changes file to be installed.
+	\$gpgkey	GnuPG key to use to sign the archive.
+        \$gpgpassfile   File to provide password to GnuPG.
+	\$inputdir	The input directory (no effect in $inputconfigfile).
 	\$lockfile	The lockfile to use, default $lockfile.
 	\@mailtos	The fields in .changes file that should be used for
 			 mailing SUCCESS and REJECT messages. If there is an
 			 @ char in the arrach it will be used directly.
+	\$majordefault  Default major section (see --majordefault above).
+	\$movecmd	The move command (see --movecmd).
         \%release	Additional information to add to generated Release
 			 files.  Supported keys are origin, label, and
 			 description.
-	\$gpgkey	GnuPG key to use to sign the archive.
-        \$gpgpassfile   File to provide password to GnuPG.
+	\$rmcmd		The remove command (see --rmcmd above).
 ";
 
 ###############################################################################
@@ -1185,8 +1192,14 @@ sub handleIndex() {
 #	Written using parts of handleSorting.
 #	Improved changes file verification structure.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
-#   Add arg to handle signature verification in inputdir and distinput-dirs
-#   independetly.
+#       Add arg to handle signature verification in inputdir and distinput-dirs
+#       independetly.
+#  2006-11-24 Håkon Stordahl <haastord@online.no>
+#       Substituted the call to rejectChangesFile with a call to pdebug,
+#       to explicitly trigger the error handler incomingError, which
+#       itself contains a call to rejectChangesFile. This is in order
+#       to avoid a situation in which an error in rejectChangesFile
+#       causes rejectChangesFile to be called again.
 ###############################################################################
 
 sub findAndSortChangesFiles($;$) {
@@ -1206,8 +1219,11 @@ sub findAndSortChangesFiles($;$) {
 		uploaderIsChangesFileOwner($cfile);
 		my ($verify, $reason) = verifyChangesFile($cfile, $verify);
 		if ($verify =~ /^reject$/) {
-		    # Reject .changes file.
-		    rejectChangesFile();
+		    # Reject .changes file by calling pdebug with error
+                    # level 2, which in turn calls the error handler
+                    # for this function, incomingError, which calls
+                    # rejectChangesFile.
+                    pdebug(2, "Rejecting $cfile.");
 		}
 		elsif ($verify =~ /^incomplete$/) {
 		    # Handle incomplete .changes file.
@@ -1239,8 +1255,8 @@ sub findAndSortChangesFiles($;$) {
 #	Broke out .changes file handling to a separate function
 #	findAndSortChangesFiles.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
-#   Add signatur checking setting to arguments given to
-#   findAndSortChangesFiles().
+#       Add signatur checking setting to arguments given to
+#       findAndSortChangesFiles().
 # Uses:		A lot.
 ###############################################################################
 
@@ -1377,8 +1393,8 @@ sub handleDebOnlyFile($$) {
 #	part. Rewrote parts to allow it to return some kind of status.
 #	Added code to verify that changes file upload is complete.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
-#   Add arg to handle signature verification in inputdir and distinput-dirs
-#   independetly.
+#       Add arg to handle signature verification in inputdir and distinput-dirs
+#       independetly.
 ###############################################################################
 
 sub verifyChangesFile($$) {
@@ -1464,7 +1480,7 @@ sub handleChangesFile($) {
 
     my $file;
     foreach $file (keys %CFiles) {
-	handlePackageFile($file);
+	handlePackageFile($file, $cfile);
     }
     installChangesFile($cfile);
     mailSuccess();
@@ -1507,7 +1523,7 @@ sub uploaderIsChangesFileOwner($) {
 #  2005-05-01 Ola Lundqvist <opal@debian.org>
 #	Modified reject cause.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
-#   Fixed move-command and check for .changes file.
+#       Fixed move-command and check for .changes file.
 ###############################################################################
 
 sub rejectChangesFile() {
@@ -1544,10 +1560,14 @@ sub rejectChangesFile() {
 # Changelog:
 #  2001-06-26 Ola Lundqvist <opal@debian.org>
 #	Taken from the main script. Cut and paste with simple changes.
+#  2006-06-11 Michael Hanke <michael.hanke@gmail.com>
+#       Only remove source tarball file if not referenced by any other .changes file.
+#  2006-07-20 Ola Lundqvist <opal@debian.org>
+#       Changed indentation.
 ###############################################################################
 
 sub handlePackageFile ($) {
-    my ($file, $action) = @_;
+    my ($file, $cfile) = @_;
     my $distrd = $CConf{Distribution};
 
     pdebug(5, "File $_:  $CFiles{$file}");
@@ -1610,10 +1630,43 @@ sub handlePackageFile ($) {
 	cmdaction("$copycmd $file $installto",
 		  "Installing $file to $installto.",
 		  2);
-    }
-    cmdaction("$rmcmd $file",
-	      "Removing $file after it has been installed.",
-	      2);
+	}
+	# flag whether file should get deleted
+	my $killfile = 1;
+		
+	# only do checks of processing source tarballs
+        if ($file =~ m/.tar.gz$/) {
+	    my @upstream_version = split(/-/, $ver);
+	    $upstream_version = $upstream_version[0];
+	    
+	    # get list of remaining *.changes files of this package upstream 
+	    # version
+	    my @otherchangesfiles = <$inputdir/${pkgname}_$upver*.changes>;
+	    
+	    # check whether any of the remaining *.changes files does not match the 
+	    # current package
+	  CHGSPARSER: foreach my $otherchangesfile (@otherchangesfiles) {
+	      if (!($otherchangesfile =~ $cfile)) {
+		  open ( otherchangesfilehandle, $otherchangesfile);
+		  
+		  while ($line = <otherchangesfilehandle>) {
+		      if ($line =~ m/${pkgname}_$upver.*\.tar\.gz/) {
+			  pdebug(4, "Found additional package using the source tarball of the package. Will not delete it now!");
+			  $killfile = 0;
+			  close(otherchangesfilehandle);
+			  last CHGSPARSER;
+		      }
+		  }
+		  
+		  close(otherchangesfilehandle)
+		  }
+	  }
+	}
+    
+	if ($killfile) {
+	    cmdaction("$rmcmd $file", 
+		      "Removing $file after it has been installed.", 2);
+	}
 }
 
 ###############################################################################
@@ -1658,6 +1711,29 @@ sub installChangesFile ($) {
 ###############################################################################
 ######################### LOCK HANDLERS #######################################
 ###############################################################################
+# Changelog:
+#  2006-11-24 Håkon Stordahl <haastord@online.no>
+#       Tried to fix the error handler functions incomingError and
+#       rejectError, by removing the lock file in rejectError instead
+#       of incomingError, so the lock file is not removed immediately
+#       after an error, but rather if another error occurs while
+#       handling the error. Also added a call to exit in rejectError
+#       so the program will terminate in this case.
+#
+#       Because of the chdir in handleSorting, the lock file name
+#       needs to prefixed by $inputdir in the functions incomingError
+#       and rejectError.
+#
+#       Restored the error handler in incomingError so subsequent
+#       errors are treated in the same way.
+#
+#       Also moved the call to mailReject from the function rejectError
+#       to the function incomingError, so a mail is sent each time
+#       a .changes file is rejected. When called from rejectError,
+#       which actually is the error handler of incomingError, which
+#       itself is an error handler and calls rejectChangesFile, a mail
+#       would only be sent if there was a problem with the rejection.
+###############################################################################
 
 sub incomingLock() {
     &createLockExit("$lockfile");
@@ -1670,15 +1746,16 @@ sub incomingRelease() {
 }
 
 sub incomingError() {
-    &setErrorHandler(undef);
-    &removeLockfile("$lockfile");    
     &setErrorHandler(\&rejectError);    
     &rejectChangesFile();
+    &mailReject();
+    &setErrorHandler(\&incomingError);
 }
 
 sub rejectError() {
     &setErrorHandler(undef);
-    &mailReject();
+    &removeLockfile("$inputdir/$lockfile");    
+    exit;
 }
 
 sub destinationLock() {
@@ -2114,81 +2191,13 @@ The file structure is based on the potato file structure and does not support pa
 
 =over 4
 
-=item B<--debug-level | --dl> level
+=item B<-a | --autoscan>
 
-What information that should be printed. 1=critical, 2=error, 3=normal, 4=message, 5=debug, 6=verbose debug (modules).
+Does both --autoscanpackages and --autoscansources.
 
-=item B<--quit-level> level
+=item B<--autoscanall>
 
-On what level to quit the application, see debug level.
-
-=item B<-v | --version>
-
-Prints the version string.
-
-=item B<--help>
-
-Prints this information.
-
-=item B<--copycmd>
-
-The install command to use, default $copycmd. Both packages and .changes files are installed using this command.
-
-=item B<--majordefault>
-
-Default major section to use if undefined (default: main)
-
-=item B<--movecmd>
-
-Command to move files (currently not used at all).
-
-=item B<--rmcmd>
-
-The remove command to use, default $rmcmd. This can be used to move away the old packages to some other place.
-
-=item B<--instcmd>
-
-DEPRECATED!
-
-=item B<-d | --dest | --destdir> dir
-
-Destination directory. The base directory where all the distribution packages reside. Here the $distrib/$major/$arch/$section directory structure will be created. Default $destdir, relative to the input directory.
-
-=item B<--scandetect | -s>
-
-Scan using apt-ftparchive or dpkg-scan* depending on what is installed on the system. This is the recommended way. Only use --index or --autoscan if you know what you are doing.
- 
-=item B<-x | --index>
-
-Automatically run apt-ftparchive after all new packages are installed.  config must be an absolute path to the configuration file to use for apt-ftparchive generate. See the apt-ftparchive manual page for more information. Use this *or* --autoscan, not both.
-
-=item B<-i | --input | --indir | --inputdir> dir
-
-This is the directory where the all packages and corresponding *.changes files that should be installed to the --dest directory, default $instdir.
-
-=item B<--cachedir> dir
-
-The apt-ftparchive package cache directory, if --index is used.  Default $cachedir.
-
-=item B<--lockfile> file
-
-The lockfile to use, default $lockfile.
-
-=item B<--cinstall> dir
-
-Where the .changes file will be installed to, empty string to remove it instead, default $cinstall.
-
-=item B<--configfile> file
-
-Specify an extra configuration file to read. Will be read after etc config and user config file.
-
-=item B<--distinputcriteria>
-
-The criteria for which binary packages that should be installed even if it does not have a .changes file, default $distinputcriteria.
- 
-=item B<-o | --addoverride>
-
-Automatically add new packages to the override file.
+Same as --scanall --autoscan.
 
 =item B<--autoscanpackages>
 
@@ -2202,18 +2211,34 @@ Automatically run dpkg-scansources after all new packages are installed.
 
 Create bzip2 compressed Packages.bz2 and Sources.bz2 files. 
 
-=item B<-a | --autoscan>
+=item B<--cachedir> dir
 
-Does both --autoscanpackages and --autoscansources.
+The apt-ftparchive package cache directory, if --index is used.  Default $cachedir.
 
-=item B<--scanall>
+=item B<--cinstall> dir
 
-Scan all distributions, sections, etc.
+Where the .changes file will be installed to, empty string to remove it instead, default $cinstall.
 
-=item B<--autoscanall>
+=item B<--configfile> file
 
-Same as --scanall --autoscan.
+Specify an extra configuration file to read. Will be read after etc config and user config file.
 
+=item B<--copycmd>
+
+The install command to use, default $copycmd. Both packages and .changes files are installed using this command.
+
+=item B<-d | --dest | --destdir> dir
+
+Destination directory. The base directory where all the distribution packages reside. Here the $distrib/$major/$arch/$section directory structure will be created. Default $destdir, relative to the input directory.
+
+=item B<--debug-level | --dl> level
+
+What information that should be printed. 1=critical, 2=error, 3=normal, 4=message, 5=debug, 6=verbose debug (modules).
+
+=item B<--distinputcriteria>
+
+The criteria for which binary packages that should be installed even if it does not have a .changes file, default $distinputcriteria.
+ 
 =item B<--gpgkey>
 
 GnuPG key to use to sign the archive.
@@ -2222,6 +2247,34 @@ GnuPG key to use to sign the archive.
 
 File to provide password to GnuPG.
 
+=item B<-i | --input | --indir | --inputdir> dir
+
+This is the directory where the all packages and corresponding *.changes files that should be installed to the --dest directory, default $instdir.
+
+=item B<--index | -x>
+
+Automatically run apt-ftparchive after all new packages are installed.  config must be an absolute path to the configuration file to use for apt-ftparchive generate. See the apt-ftparchive manual page for more information. Use this *or* --autoscan, not both.
+
+=item B<--instcmd>
+
+DEPRECATED!
+
+=item B<--help>
+
+Prints this information.
+
+=item B<--lockfile> file
+
+The lockfile to use, default $lockfile.
+
+=item B<--majordefault>
+
+Default major section to use if undefined (default: main)
+
+=item B<--movecmd>
+
+Command to move files (currently not used at all).
+
 =item B<--nosort>
 
 Do not sort packages.
@@ -2230,50 +2283,58 @@ Do not sort packages.
 
 Do not create directories and touch Package files.
 
+=item B<-o | --addoverride>
+
+Automatically add new packages to the override file.
+
+=item B<--rmcmd>
+
+The remove command to use, default $rmcmd. This can be used to move away the old packages to some other place.
+
+=item B<--scanall>
+
+Scan all distributions, sections, etc.
+
+=item B<--scandetect | -s>
+
+Scan using apt-ftparchive or dpkg-scan* depending on what is installed on the system. This is the recommended way. Only use --index or --autoscan if you know what you are doing.
+ 
 =item B<--scanonly>
 
 Same as --nosort --nostructurefix.
 
+=item B<--quit-level> level
+
+On what level to quit the application, see debug level.
+
+=item B<-v | --version>
+
+Prints the version string.
+
 =head1 CONFIG FILE
 
 You can also place config files with the following names (in following order) /etc/debarchiver.conf, ~/.debarchiver.conf and input.conf (relative to input directory) that will be read before, the arguments to this program will be parsed. Here you can change the following variables:
 
-=item B<$destdir>
+=item B<$bzip>
 
-The destination directory (see --destdir above).
-
-=item B<$inputdir>
-
-The input directory (no effect in $inputconfigfile).
+If set to 0 no bzip2 files will be generated. If set to 1 bzip2 files will
+be generated.
 
 =item B<$cachedir>
 
 The cache directory for apt-ftparchive, used if --index is used.
 
-=item B<$copycmd>
-
-The install command (see --copycmd).
-
-=item B<$majordefault>
-
-Default major section (see --majordefault above).
-
-=item B<$movecmd>
-
-The move command (see --movecmd).
-
-=item B<$rmcmd>
-
-The remove command (see --rmcmd above).
-
 =item B<$cinstall>
 
 Where the .changes files are installed (see --cinstall above).
 
-=item B<$bzip>
+=item B<$copycmd>
 
-If set to 0 no bzip2 files will be generated. If set to 1 bzip2 files will
-be generated.
+The install command (see --copycmd).
+
+=item B<$destdir>
+
+The destination directory (see --destdir above).
 
 =item B<$distinputcriteria>
 
@@ -2283,13 +2344,18 @@ The criteria for which packages that should be installed even if it does not hav
 
 Directories (distribution => dir) to be searched for binary packages that do not need a .changes file to be installed but match $distinputcriteria.  The default is kernel packages generated by make-kpkg which does not generate a .changes file.  Additionally binary packages with a valid .changes file will have the default distribution overridden to be the current queue directory.  This causes uploads to a specific queue to place the package into that distribution directly.
 
-=item B<$verifysignatures>
+=item B<$gpgkey>
 
-Choose to enable (1) or disable (0) signature verification for packages uploaded into $inputdir (not %distinputdirs).
+GnuPG key to use to sign the archive.  If this variable is set, the Release file for each changed section of the archive will be signed with GnuPG using $gpgkey as the key ID.  Unless you use a key that has no passphrase or use $gpgpassfile, you will need to run B<debarchiver> interactively when using this option so that you can supply the passphrase.
 
-=item B<$verifysignaturesdistinput>
+=item B<$gpgpassfile>
 
-Choose to enable (1) or disable (2) signature verification for packages uploaded into %distinputdirs. This works independently from $verifysignatures.
+A file that contain the passphrase for the GnuPG key. See $gpgkey for more
+information.
+
+=item B<$inputdir>
+
+The input directory (no effect in $inputconfigfile).
 
 =item B<$lockfile>
 
@@ -2299,18 +2365,29 @@ The lockfile to use, default $lockfile.
 
 An array of strings that should be mailed to. If the string contains an email address that one is used. If it contains an incomplete email address, i.e. @hostname, the username owning the file is used @ the hostname specified. If no @ character is found in the string, it is considered as a field in the .changes file. Such a field can for example be Maintainer or Uploaders.
 
+=item B<$majordefault>
+
+Default major section (see --majordefault above).
+
+=item B<$movecmd>
+
+The move command (see --movecmd).
+
 =item B<%release>
 
 Additional information to add to generated Release files.  Supported keys are origin, label, and description.
 
-=item B<$gpgkey>
+=item B<$rmcmd>
 
-GnuPG key to use to sign the archive.  If this variable is set, the Release file for each changed section of the archive will be signed with GnuPG using $gpgkey as the key ID.  Unless you use a key that has no passphrase or use $gpgpassfile, you will need to run B<debarchiver> interactively when using this option so that you can supply the passphrase.
+The remove command (see --rmcmd above).
 
-=item B<$gpgpassfile>
+=item B<$verifysignatures>
 
-A file that contain the passphrase for the GnuPG key. See $gpgkey for more
-information.
+Choose to enable (1) or disable (0) signature verification for packages uploaded into $inputdir (not %distinputdirs).
+
+=item B<$verifysignaturesdistinput>
+
+Choose to enable (1) or disable (2) signature verification for packages uploaded into %distinputdirs. This works independently from $verifysignatures.
 
 =back
 
